@@ -113,7 +113,7 @@ namespace RTT
          * @param initial_state Provide the \a PreOperational parameter flag here
          * to force users in calling configure(), before they call start().
          */
-        TaskCore( TaskState initial_state = Stopped, const std::string& name = std::string() );
+        TaskCore( TaskState initial_state = Stopped );
 
         virtual ~TaskCore();
 
@@ -336,6 +336,18 @@ namespace RTT
         unsigned int getTimeOutCounter() const { return mTimeOutCounter; }
 
     protected:
+        /** Change the current state
+         *
+         * Virtual to allow subclasses to listen to state changes
+         */
+        virtual void setTaskState(TaskState state);
+
+        /** Change the current state
+         *
+         * Virtual to allow subclasses to listen to state changes
+         */
+        virtual void setTargetState(TaskState state);
+
         /**
          * Implement this method such that it contains the code which
          * will be executed when \a configure() is called. The default
@@ -486,11 +498,6 @@ namespace RTT
          * Number of cycles that were caused by Trigger triggers.
          */
         unsigned int mTriggerCounter;
-
-        /** The name of this task. This is used only for debugging / tracing
-         * purposes
-         */
-        std::string mName;
     };
 }}
 
