@@ -37,53 +37,30 @@
 
 
 #include "SlaveActivity.hpp"
-
-#include "../base/DisposableInterface.hpp"
 #include "../os/MainThread.hpp"
-#include "ExecutionEngine.hpp"
 #include "Logger.hpp"
 
 namespace RTT {
     using namespace extras;
     using namespace base;
-
-    class TriggerSlaveActivity : public base::DisposableInterface {
-    public:
-        SlaveActivity* mslave;
-        TriggerSlaveActivity(SlaveActivity* act) : mslave(act) {}
-        virtual void executeAndDispose() {
-            base::RunnableInterface *runner = mslave->getRunner();
-            if (runner) {
-                runner->work(RunnableInterface::Trigger);
-            } else {
-                mslave->work(RunnableInterface::Trigger);
-            }
-        }
-        virtual void dispose() {}
-    };
-
     SlaveActivity::SlaveActivity( ActivityInterface* master, RunnableInterface* run /*= 0*/ )
-        :ActivityInterface(run), mmaster(master), mperiod( master->getPeriod() ), running(false), active(false),
-        mtrigger(new TriggerSlaveActivity(this))
+        :ActivityInterface(run), mmaster(master), mperiod( master->getPeriod() ), running(false), active(false)
     {
     }
 
     SlaveActivity::SlaveActivity( double period, RunnableInterface* run /*= 0*/ )
-        :ActivityInterface(run), mmaster(0), mperiod(period), running(false), active(false),
-        mtrigger(new TriggerSlaveActivity(this))
+        :ActivityInterface(run), mmaster(0), mperiod(period), running(false), active(false)
     {
     }
 
     SlaveActivity::SlaveActivity( RunnableInterface* run /*= 0*/ )
-        :ActivityInterface(run), mmaster(0), mperiod(0.0), running(false), active(false),
-        mtrigger(new TriggerSlaveActivity(this))
+        :ActivityInterface(run), mmaster(0), mperiod(0.0), running(false), active(false)
     {
     }
 
     SlaveActivity::~SlaveActivity()
     {
         stop();
-        delete mtrigger;
     }
 
     Seconds SlaveActivity::getPeriod() const
@@ -117,6 +94,11 @@ namespace RTT {
         return mmaster ? mmaster->thread() : os::MainThread::Instance();
     }
 
+    base::ActivityInterface *SlaveActivity::getMaster() const
+    {
+        return mmaster;
+    }
+
     bool SlaveActivity::initialize()
     {
         return true;
@@ -205,17 +187,16 @@ namespace RTT {
 
     bool SlaveActivity::trigger()
     {
-        if (!mmaster) { return false; }
-
-        ExecutionEngine *engine = dynamic_cast<ExecutionEngine *>(mmaster->getRunner());
-        if (!engine) { return false; }
-        return engine->process(mtrigger);
+        if (mmaster)
+            return mmaster->trigger();
+        return false;
     }
 
     bool SlaveActivity::timeout()
     {
-        if (!mmaster) { return false; }
-        return mmaster->timeout();
+        if (mmaster)
+            return mmaster->timeout();
+        return false;
     }
 
     bool SlaveActivity::execute()
@@ -250,4 +231,5 @@ namespace RTT {
         return running;
     }
 
+
 }
