@@ -198,70 +198,81 @@ namespace RTT
         // Detect already added parts of an interface, does not yet detect removed parts...
         if (CORBA::is_nil(mtask))
             return;
+        
+        CService_var serv = mtask->getProvider("this");
+        this->fetchServices(this->provides(), serv.in() );
 
-        CTaskContextDescription_var tcd = mtask->getCTaskContextDescription();
-
-        CService_var serv = tcd->mainprovider;
-        synchronizeServices(this->provides(), serv.in(), tcd->mainprovider_description);
-
-        CServiceRequester_var srq = tcd->mainrequester;
-        synchronizeRequesters(this->requires(), srq, tcd->mainrequester_description);
-
+        CServiceRequester_var srq = mtask->getRequester("this");
+        this->fetchRequesters(this->requires(), srq.in() );
         log(Debug) << "All Done."<<endlog();
     }
 
-    void TaskContextProxy::synchronizeRequesters(ServiceRequester::shared_ptr parent, CServiceRequester_ptr csrq, const CServiceRequesterDescription & cdescription)
+    void TaskContextProxy::fetchRequesters(ServiceRequester::shared_ptr parent, CServiceRequester_ptr csrq)
     {
-        for ( size_t i=0; i < cdescription.operationcallernames.length(); ++i) {
-            if ( parent->getOperationCaller( string(cdescription.operationcallernames[i].in() )))
+        COperationCallerNames_var opcnames = csrq->getOperationCallerNames();
+
+        log(Debug) << "Fetching OperationCallers of " << parent->getRequestName()<<endlog();
+        for ( size_t i=0; i < opcnames->length(); ++i) {
+            if ( parent->getOperationCaller( string(opcnames[i].in() )))
                 continue; // already added.
-            log(Debug) << "Requiring operation: "<< cdescription.operationcallernames[i].in() <<endlog();
-            parent->addOperationCaller( * new OperationCallerProxy(string(cdescription.operationcallernames[i].in() ), CServiceRequester::_duplicate(csrq) ));
+            log(Debug) << "Requiring operation: "<< opcnames[i].in() <<endlog();
+            parent->addOperationCaller( * new OperationCallerProxy(string(opcnames[i].in() ), CServiceRequester::_duplicate(csrq) ));
         }
 
-        assert(cdescription.children.length() == cdescription.children_descriptions.length());
-        for( size_t i =0; i != cdescription.children.length(); ++i) {
-            CServiceRequester_ptr cobj = cdescription.children[i];
-            ServiceRequester::shared_ptr tobj = this->requires(std::string(cdescription.children_descriptions[i].name));
+        CRequestNames_var rqlist = csrq->getRequestNames();
+
+        for( size_t i =0; i != rqlist->length(); ++i) {
+            if ( string( rqlist[i] ) == "this")
+                continue;
+            CServiceRequester_var cobj = csrq->getRequest(rqlist[i]);
+
+            ServiceRequester::shared_ptr tobj = this->requires(std::string(rqlist[i]));
 
             // Recurse:
-            this->synchronizeRequesters(tobj, cobj, cdescription.children_descriptions[i]);
+            this->fetchRequesters( tobj, cobj.in() );
         }
     }
 
-    void TaskContextProxy::synchronizeServices(Service::shared_ptr parent, CService_ptr serv, const CServiceDescription & cdescription)
+    // Recursively fetch remote objects and create local proxies.
+    void TaskContextProxy::fetchServices(Service::shared_ptr parent, CService_ptr serv)
     {
-        log(Debug) << "Synchronizing "<<parent->getName()<<" Service:"<<endlog();
+        log(Debug) << "Fetching "<<parent->getName()<<" Service:"<<endlog();
 
         // Fetch ports
-        this->synchronizePorts(parent, serv, cdescription);
+        this->fetchPorts(parent, serv);
 
         // load command and method factories.
         // methods:
-        log(Debug) << "Synchronizing Operations."<<endlog();
-        for ( size_t i=0; i < cdescription.operations.length(); ++i) {
-            if ( parent->hasMember( string(cdescription.operations[i].name.in() )))
+        log(Debug) << "Fetching Operations."<<endlog();
+        COperationInterface::COperationList_var objs;
+        objs = serv->getOperations();
+        for ( size_t i=0; i < objs->length(); ++i) {
+            if ( parent->hasMember( string(objs[i].in() )))
                 continue; // already added.
-            log(Debug) << "Providing operation: "<< cdescription.operations[i].name.in() <<endlog();
-            parent->add( cdescription.operations[i].name.in(), new CorbaOperationCallerFactory( cdescription.operations[i], serv, ProxyPOA() ) );
+            log(Debug) << "Providing operation: "<< objs[i].in() <<endlog();
+            parent->add( objs[i].in(), new CorbaOperationCallerFactory( objs[i].in(), serv, ProxyPOA() ) );
         }
 
         // first do properties:
-        log(Debug) << "Synchronizing Properties."<<endlog();
-        for (size_t i=0; i != cdescription.properties.length(); ++i) {
-            if ( findProperty( *parent->properties(), string(cdescription.properties[i].name.in()), "." ) )
+        log(Debug) << "Fetching Properties."<<endlog();
+        // a dot-separated list of subbags and items
+        CConfigurationInterface::CPropertyNames_var props = serv->getPropertyList();
+
+        for (size_t i=0; i != props->length(); ++i) {
+            if ( findProperty( *parent->properties(), string(props[i].name.in()), "." ) )
                 continue; // previously added.
-//            if ( !serv->hasProperty( cdescription.properties[i].name.in() ) ) {
-//                log(Error) <<"Property "<< string(cdescription.properties[i].name.in()) << " present in getPropertyList() but not accessible."<<endlog();
-//                continue;
-//            }
-            // If the type is known, immediately build the correct property and datasource.
-            TypeInfo* ti = TypeInfoRepository::Instance()->type( cdescription.properties[i].type_name.in() );
+            if ( !serv->hasProperty( props[i].name.in() ) ) {
+                log(Error) <<"Property "<< string(props[i].name.in()) << " present in getPropertyList() but not accessible."<<endlog();
+                continue;
+            }
+           // If the type is known, immediately build the correct property and datasource.
+            CORBA::String_var tn = serv->getPropertyTypeName(props[i].name.in());
+            TypeInfo* ti = TypeInfoRepository::Instance()->type( tn.in() );
 
             // decode the prefix and property name from the given name:
-            string pname = string( cdescription.properties[i].name.in() );
+            string pname = string( props[i].name.in() );
             pname = pname.substr( pname.rfind(".") + 1 );
-            string prefix = string( cdescription.properties[i].name.in() );
+            string prefix = string( props[i].name.in() );
             if ( prefix.rfind(".") == string::npos ) {
                 prefix.clear();
             }
@@ -273,242 +284,97 @@ namespace RTT
                 CorbaTypeTransporter* ctt = dynamic_cast<CorbaTypeTransporter*>(ti->getProtocol(ORO_CORBA_PROTOCOL_ID));
                 assert(ctt);
                 // data source needs full remote path name
-                DataSourceBase::shared_ptr ds = ctt->createPropertyDataSource( serv, cdescription.properties[i].name.in() );
-                storeProperty( *parent->properties(), prefix, ti->buildProperty( pname, cdescription.properties[i].description.in(), ds));
-                log(Debug) << "Looked up Property " << cdescription.properties[i].type_name.in() << " "<< pname <<": created."<<endlog();
+                DataSourceBase::shared_ptr ds = ctt->createPropertyDataSource( serv, props[i].name.in() );
+                storeProperty( *parent->properties(), prefix, ti->buildProperty( pname, props[i].description.in(), ds));
+                log(Debug) << "Looked up Property " << tn.in() << " "<< pname <<": created."<<endlog();
             }
             else {
-                if ( string("PropertyBag") == cdescription.properties[i].type_name.in() ) {
-                    storeProperty(*parent->properties(), prefix, new Property<PropertyBag>( pname, cdescription.properties[i].description.in()) );
-                    log(Debug) << "Looked up PropertyBag " << cdescription.properties[i].type_name.in() << " "<< pname <<": created."<<endlog();
+                if ( string("PropertyBag") == tn.in() ) {
+                    storeProperty(*parent->properties(), prefix, new Property<PropertyBag>( pname, props[i].description.in()) );
+                    log(Debug) << "Looked up PropertyBag " << tn.in() << " "<< pname <<": created."<<endlog();
                 } else
-                    log(Error) << "Looked up Property " << cdescription.properties[i].type_name.in() << " "<< pname <<": type not known. Check your RTT_COMPONENT_PATH ( \""<<getenv("RTT_COMPONENT_PATH")<<" \")."<<endlog();
+                    log(Error) << "Looked up Property " << tn.in() << " "<< pname <<": type not known. Check your RTT_COMPONENT_PATH ( \""<<getenv("RTT_COMPONENT_PATH")<<" \")."<<endlog();
             }
         }
 
-        log(Debug) << "Synchronizing Attributes."<<endlog();
-        for (size_t i=0; i != cdescription.attributes.length(); ++i) {
-            if ( parent->hasAttribute( string(cdescription.attributes[i].name.in()) ) )
+        log(Debug) << "Fetching Attributes."<<endlog();
+        CConfigurationInterface::CAttributeNames_var attrs = serv->getAttributeList();
+        for (size_t i=0; i != attrs->length(); ++i) {
+            if ( parent->hasAttribute( string(attrs[i].in()) ) )
                 continue; // previously added.
-#if 0
-            if ( !serv->hasAttribute( cdescription.attributes[i].name.in() ) ) {
-                log(Error) <<"Attribute '"<< string(cdescription.attributes[i].name.in()) << "' present in getAttributeList() but not accessible."<<endlog();
+            if ( !serv->hasAttribute( attrs[i].in() ) ) {
+                log(Error) <<"Attribute '"<< string(attrs[i].in()) << "' present in getAttributeList() but not accessible."<<endlog();
                 continue;
             }
-#endif
             // If the type is known, immediately build the correct attribute and datasource,
-            TypeInfo* ti = TypeInfoRepository::Instance()->type( cdescription.attributes[i].type_name.in() );
+            CORBA::String_var tn = serv->getAttributeTypeName( attrs[i].in() );
+            TypeInfo* ti = TypeInfoRepository::Instance()->type( tn.in() );
             if ( ti && ti->hasProtocol(ORO_CORBA_PROTOCOL_ID) ) {
-                log(Debug) << "Looking up Attribute " << cdescription.attributes[i].type_name.in() <<": found!"<<endlog();
+                log(Debug) << "Looking up Attribute " << tn.in() <<": found!"<<endlog();
                 CorbaTypeTransporter* ctt = dynamic_cast<CorbaTypeTransporter*>(ti->getProtocol(ORO_CORBA_PROTOCOL_ID));
                 assert(ctt);
                 // this function should check itself for const-ness of the remote Attribute:
-                DataSourceBase::shared_ptr ds = ctt->createAttributeDataSource( serv, cdescription.attributes[i].name.in(), cdescription.attributes[i].assignable );
-                if ( cdescription.attributes[i].assignable )
-                    parent->setValue( ti->buildAttribute( cdescription.attributes[i].name.in(), ds));
+                DataSourceBase::shared_ptr ds = ctt->createAttributeDataSource( serv, attrs[i].in() );
+                if ( serv->isAttributeAssignable( attrs[i].in() ) )
+                    parent->setValue( ti->buildAttribute( attrs[i].in(), ds));
                 else
-                    parent->setValue( ti->buildConstant( cdescription.attributes[i].name.in(), ds));
+                    parent->setValue( ti->buildConstant( attrs[i].in(), ds));
             } else {
-                log(Error) << "Looking up Attribute '" << cdescription.attributes[i].name.in() << "' of type " << cdescription.attributes[i].type_name.in() << ": ";
-                if (!ti) {
-                    log() << ": type not known. Check your RTT_COMPONENT_PATH ( \""<<getenv("RTT_COMPONENT_PATH")<<" \")." << endlog();
-                } else {
-                    log() << ": type does not support CORBA (no transport plugin loaded)" << endlog();
-                }
+                log(Error) << "Looking up Attribute " << tn.in();
+                Logger::log() <<": type not known. Check your RTT_COMPONENT_PATH ( \""<<getenv("RTT_COMPONENT_PATH")<<" \")."<<endlog();
             }
         }
 
-        assert(cdescription.children.length() == cdescription.children_descriptions.length());
-        for( size_t i =0; i != cdescription.children.length(); ++i) {
-            CService_ptr cobj = cdescription.children[i];
-            Service::shared_ptr tobj = parent->provides(std::string(cdescription.children_descriptions[i].name));
-            tobj->doc( cdescription.children_descriptions[i].description.in() );
+        CService::CProviderNames_var plist = serv->getProviderNames();
+
+        for( size_t i =0; i != plist->length(); ++i) {
+            if ( string( plist[i] ) == "this")
+                continue;
+            CService_var cobj = serv->getService(plist[i]);
+            CORBA::String_var descr = cobj->getServiceDescription();
+
+            Service::shared_ptr tobj = parent->provides(std::string(plist[i]));
+            tobj->doc( descr.in() );
 
             // Recurse:
-            this->synchronizeServices(tobj, cobj, cdescription.children_descriptions[i]);
+            this->fetchServices( tobj, cobj.in() );
         }
     }
 
-    void TaskContextProxy::synchronizePorts(Service::shared_ptr parent, CDataFlowInterface_ptr dfact, const CServiceDescription & cdescription)
+    // Fetch remote ports and create local proxies
+    void TaskContextProxy::fetchPorts(RTT::Service::shared_ptr parent, CDataFlowInterface_ptr dfact)
     {
-        log(Debug) << "Synchronizing Ports for service "<<parent->getName()<<"."<<endlog();
+        log(Debug) << "Fetching Ports for service "<<parent->getName()<<"."<<endlog();
         TypeInfoRepository::shared_ptr type_repo = TypeInfoRepository::Instance();
         if (dfact) {
-            for ( size_t i=0; i < cdescription.ports.length(); ++i) {
-                if (parent->getPort( cdescription.ports[i].name.in() ))
+            CDataFlowInterface::CPortDescriptions_var objs = dfact->getPortDescriptions();
+            for ( size_t i=0; i < objs->length(); ++i) {
+                CPortDescription port = objs[i];
+                if (parent->getPort( port.name.in() ))
                     continue; // already added.
 
-                TypeInfo const* type_info = type_repo->type(cdescription.ports[i].type_name.in());
+                TypeInfo const* type_info = type_repo->type(port.type_name.in());
                 if (!type_info)
                 {
-                    log(Warning) << "remote port '" << cdescription.ports[i].name << "' "
-                        << " has unknown type " << cdescription.ports[i].type_name << " and cannot be marshalled over CORBA. "
-                        << "It is ignored by TaskContextProxy" << endlog();
-                }
-                else if (!type_info->hasProtocol(ORO_CORBA_PROTOCOL_ID))
-                {
-                    log(Warning) << "remote port '" << cdescription.ports[i].name << "' "
-                        << " has type " << cdescription.ports[i].type_name << " which cannot be marshalled over CORBA. "
+                    log(Warning) << "remote port " << port.name
+                        << " has a type that cannot be marshalled over CORBA: " << port.type_name << ". "
                         << "It is ignored by TaskContextProxy" << endlog();
                 }
                 else
                 {
                     PortInterface* new_port;
-                    if (cdescription.ports[i].type == RTT::corba::CInput)
-                        new_port = new RemoteInputPort( type_info, dfact, cdescription.ports[i].name.in(), ProxyPOA() );
+                    if (port.type == RTT::corba::CInput)
+                        new_port = new RemoteInputPort( type_info, dfact, port.name.in(), ProxyPOA() );
                     else
-                        new_port = new RemoteOutputPort( type_info, dfact, cdescription.ports[i].name.in(), ProxyPOA() );
+                        new_port = new RemoteOutputPort( type_info, dfact, port.name.in(), ProxyPOA() );
 
-                    new_port->doc(cdescription.ports[i].description.in());
-                    parent->addLocalPort(*new_port);
+                    parent->addPort(*new_port);
                     port_proxies.push_back(new_port); // see comment in definition of port_proxies
                 }
             }
         }
     }
 
-//    // Recursively fetch remote objects and create local proxies.
-//    void TaskContextProxy::fetchServices(Service::shared_ptr parent, CService_ptr serv)
-//    {
-//        log(Debug) << "Fetching "<<parent->getName()<<" Service:"<<endlog();
-
-//        // Fetch ports
-//        this->fetchPorts(parent, serv);
-
-//        // load command and method factories.
-//        // methods:
-//        log(Debug) << "Fetching Operations."<<endlog();
-//        COperationInterface::COperationList_var objs;
-//        objs = serv->getOperations();
-//        for ( size_t i=0; i < objs->length(); ++i) {
-//            if ( parent->hasMember( string(objs[i].in() )))
-//                continue; // already added.
-//            log(Debug) << "Providing operation: "<< objs[i].in() <<endlog();
-//            parent->add( objs[i].in(), new CorbaOperationCallerFactory( objs[i].in(), serv, ProxyPOA() ) );
-//        }
-
-//        // first do properties:
-//        log(Debug) << "Fetching Properties."<<endlog();
-//        // a dot-separated list of subbags and items
-//        CConfigurationInterface::CPropertyNames_var props = serv->getPropertyList();
-
-//        for (size_t i=0; i != props->length(); ++i) {
-//            if ( findProperty( *parent->properties(), string(props[i].name.in()), "." ) )
-//                continue; // previously added.
-//            if ( !serv->hasProperty( props[i].name.in() ) ) {
-//                log(Error) <<"Property "<< string(props[i].name.in()) << " present in getPropertyList() but not accessible."<<endlog();
-//                continue;
-//            }
-//           // If the type is known, immediately build the correct property and datasource.
-//            CORBA::String_var tn = serv->getPropertyTypeName(props[i].name.in());
-//            TypeInfo* ti = TypeInfoRepository::Instance()->type( tn.in() );
-
-//            // decode the prefix and property name from the given name:
-//            string pname = string( props[i].name.in() );
-//            pname = pname.substr( pname.rfind(".") + 1 );
-//            string prefix = string( props[i].name.in() );
-//            if ( prefix.rfind(".") == string::npos ) {
-//                prefix.clear();
-//            }
-//            else {
-//                prefix = prefix.substr( 0, prefix.rfind(".") );
-//            }
-
-//            if ( ti && ti->hasProtocol(ORO_CORBA_PROTOCOL_ID)) {
-//                CorbaTypeTransporter* ctt = dynamic_cast<CorbaTypeTransporter*>(ti->getProtocol(ORO_CORBA_PROTOCOL_ID));
-//                assert(ctt);
-//                // data source needs full remote path name
-//                DataSourceBase::shared_ptr ds = ctt->createPropertyDataSource( serv, props[i].name.in() );
-//                storeProperty( *parent->properties(), prefix, ti->buildProperty( pname, props[i].description.in(), ds));
-//                log(Debug) << "Looked up Property " << tn.in() << " "<< pname <<": created."<<endlog();
-//            }
-//            else {
-//                if ( string("PropertyBag") == tn.in() ) {
-//                    storeProperty(*parent->properties(), prefix, new Property<PropertyBag>( pname, props[i].description.in()) );
-//                    log(Debug) << "Looked up PropertyBag " << tn.in() << " "<< pname <<": created."<<endlog();
-//                } else
-//                    log(Error) << "Looked up Property " << tn.in() << " "<< pname <<": type not known. Check your RTT_COMPONENT_PATH ( \""<<getenv("RTT_COMPONENT_PATH")<<" \")."<<endlog();
-//            }
-//        }
-
-//        log(Debug) << "Fetching Attributes."<<endlog();
-//        CConfigurationInterface::CAttributeNames_var attrs = serv->getAttributeList();
-//        for (size_t i=0; i != attrs->length(); ++i) {
-//            if ( parent->hasAttribute( string(attrs[i].in()) ) )
-//                continue; // previously added.
-//            if ( !serv->hasAttribute( attrs[i].in() ) ) {
-//                log(Error) <<"Attribute '"<< string(attrs[i].in()) << "' present in getAttributeList() but not accessible."<<endlog();
-//                continue;
-//            }
-//            // If the type is known, immediately build the correct attribute and datasource,
-//            CORBA::String_var tn = serv->getAttributeTypeName( attrs[i].in() );
-//            TypeInfo* ti = TypeInfoRepository::Instance()->type( tn.in() );
-//            if ( ti && ti->hasProtocol(ORO_CORBA_PROTOCOL_ID) ) {
-//                log(Debug) << "Looking up Attribute " << tn.in() <<": found!"<<endlog();
-//                CorbaTypeTransporter* ctt = dynamic_cast<CorbaTypeTransporter*>(ti->getProtocol(ORO_CORBA_PROTOCOL_ID));
-//                assert(ctt);
-//                // this function should check itself for const-ness of the remote Attribute:
-//                DataSourceBase::shared_ptr ds = ctt->createAttributeDataSource( serv, attrs[i].in() );
-//                if ( serv->isAttributeAssignable( attrs[i].in() ) )
-//                    parent->setValue( ti->buildAttribute( attrs[i].in(), ds));
-//                else
-//                    parent->setValue( ti->buildConstant( attrs[i].in(), ds));
-//            } else {
-//                log(Error) << "Looking up Attribute " << tn.in();
-//                Logger::log() <<": type not known. Check your RTT_COMPONENT_PATH ( \""<<getenv("RTT_COMPONENT_PATH")<<" \")."<<endlog();
-//            }
-//        }
-
-//        CService::CProviderNames_var plist = serv->getProviderNames();
-
-//        for( size_t i =0; i != plist->length(); ++i) {
-//            if ( string( plist[i] ) == "this")
-//                continue;
-//            CService_var cobj = serv->getService(plist[i]);
-//            CORBA::String_var descr = cobj->getServiceDescription();
-
-//            Service::shared_ptr tobj = parent->provides(std::string(plist[i]));
-//            tobj->doc( descr.in() );
-
-//            // Recurse:
-//            this->fetchServices( tobj, cobj.in() );
-//        }
-//    }
-
-//    // Fetch remote ports and create local proxies
-//    void TaskContextProxy::fetchPorts(RTT::Service::shared_ptr parent, CDataFlowInterface_ptr dfact)
-//    {
-//        log(Debug) << "Fetching Ports for service "<<parent->getName()<<"."<<endlog();
-//        TypeInfoRepository::shared_ptr type_repo = TypeInfoRepository::Instance();
-//        if (dfact) {
-//            CDataFlowInterface::CPortDescriptions_var objs = dfact->getPortDescriptions();
-//            for ( size_t i=0; i < objs->length(); ++i) {
-//                CPortDescription port = objs[i];
-//                if (parent->getPort( port.name.in() ))
-//                    continue; // already added.
-
-//                TypeInfo const* type_info = type_repo->type(port.type_name.in());
-//                if (!type_info)
-//                {
-//                    log(Warning) << "remote port " << port.name
-//                        << " has a type that cannot be marshalled over CORBA: " << port.type_name << ". "
-//                        << "It is ignored by TaskContextProxy" << endlog();
-//                }
-//                else
-//                {
-//                    PortInterface* new_port;
-//                    if (port.type == RTT::corba::CInput)
-//                        new_port = new RemoteInputPort( type_info, dfact, port.name.in(), ProxyPOA() );
-//                    else
-//                        new_port = new RemoteOutputPort( type_info, dfact, port.name.in(), ProxyPOA() );
-
-//                    parent->addLocalPort(*new_port);
-//                    port_proxies.push_back(new_port); // see comment in definition of port_proxies
-//                }
-//            }
-//        }
-//    }
-
     void TaskContextProxy::DestroyOrb()
     {
         try {
@@ -542,10 +408,7 @@ namespace RTT
             return ctp;
         }
         catch( IllegalServer& is ) {
-            log(Error) << is.what() << endlog();
-        }
-        catch (CORBA::Exception &e) {
-            log(Error) << "TaskContextProxy::Create: CORBA exception raised!" << Logger::nl << CORBA_EXCEPTION_INFO(e) << endlog();
+            cerr << is.what() << endl;
         }
         return 0;
     }
@@ -603,12 +466,8 @@ namespace RTT
             return ctp;
         }
         catch( IllegalServer& is ) {
-            log(Error) << is.what() << endlog();
+            cerr << is.what() << endl;
         }
-        catch (CORBA::Exception &e) {
-            log(Error) << "TaskContextProxy::Create: CORBA exception raised!" << Logger::nl << CORBA_EXCEPTION_INFO(e) << endlog();
-        }
-
         return 0;
     }
 
