@@ -35,8 +35,6 @@
 #include <transports/corba/CorbaConnPolicy.hpp>
 #include <transports/corba/RTTCorbaConversion.hpp>
 
-#include <boost/scoped_ptr.hpp>
-
 #include "operations_fixture.hpp"
 
 #include <memory>
@@ -413,7 +411,7 @@ BOOST_AUTO_TEST_CASE( testOperationCallerC_Send )
     BOOST_CHECK_EQUAL( r, 0.0 );
     BOOST_CHECK_EQUAL( cr, -5.0 );
 
-#ifndef RTT_CORBA_SEND_ONEWAY_OPERATIONS
+    
     mc = tp->provides("methods")->create("m0except", caller->engine());
     BOOST_CHECK_NO_THROW( mc.check() );
     shc = mc.send();
@@ -422,7 +420,6 @@ BOOST_AUTO_TEST_CASE( testOperationCallerC_Send )
     // now collect:
     BOOST_CHECK_THROW( shc.collect(), std::runtime_error);
     BOOST_REQUIRE( tc->inException() );
-#endif
 }
 
 BOOST_AUTO_TEST_CASE( testRemoteOperationCallerCall )
@@ -528,7 +525,7 @@ BOOST_AUTO_TEST_CASE(testDataFlowInterface)
     corba::CDataFlowInterface_var ports = ts->server()->ports();
 
     corba::CDataFlowInterface::CPortNames_var names =
-    ports->getPorts();
+	ports->getPorts();
 
     BOOST_CHECK_EQUAL(CORBA::ULong(2), names->length());
     BOOST_CHECK_EQUAL(string("mi"), string(names[CORBA::ULong(0)]));
@@ -536,14 +533,14 @@ BOOST_AUTO_TEST_CASE(testDataFlowInterface)
 
     // Now check directions
     BOOST_CHECK_EQUAL(RTT::corba::COutput,
-        ports->getPortType("mo"));
+	    ports->getPortType("mo"));
     BOOST_CHECK_EQUAL(RTT::corba::CInput,
-        ports->getPortType("mi"));
+	    ports->getPortType("mi"));
 
     // And check type names
-    CORBA::String_var cstr = ports->getDataType("mo");
+	CORBA::String_var cstr = ports->getDataType("mo");
     BOOST_CHECK_EQUAL(string("double"),
-        string(cstr.in()));
+	    string(cstr.in()));
 }
 
 BOOST_AUTO_TEST_CASE( testPortConnections )
@@ -584,9 +581,7 @@ BOOST_AUTO_TEST_CASE( testPortConnections )
     policy.type = RTT::corba::CData;
     policy.pull = true;
     BOOST_CHECK( ports->createConnection("mo", ports2, "mi", policy) );
-#ifndef RTT_CORBA_PORTS_DISABLE_SIGNAL
     testPortDataConnection();
-#endif // RTT_CORBA_PORTS_DISABLE_SIGNAL
     ports2->disconnectPort("mi");
     testPortDisconnected();
 
@@ -601,9 +596,7 @@ BOOST_AUTO_TEST_CASE( testPortConnections )
     policy.type = RTT::corba::CBuffer;
     policy.pull = true;
     BOOST_CHECK( ports->createConnection("mo", ports2, "mi", policy) );
-#ifndef RTT_CORBA_PORTS_DISABLE_SIGNAL
     testPortBufferConnection();
-#endif // RTT_CORBA_PORTS_DISABLE_SIGNAL
     // Here, check removal of specific connections. So first add another
     // connection ...
     mo1->createConnection(*mi1);
@@ -615,131 +608,6 @@ BOOST_AUTO_TEST_CASE( testPortConnections )
     BOOST_CHECK(!mi2->connected());
 }
 
-BOOST_AUTO_TEST_CASE( testSharedConnections )
-{
-    // This test installs shared connections between mo1 and mo2 as writers and mi2 and mi3 as readers
-
-//    // Add a second input port mo3 to tc
-//    boost::scoped_ptr<RTT::OutputPort<double> > mo3(new RTT::OutputPort<double>());
-//    tc->addPort("mo3", *mo3);
-
-    // Add a second input port mi3 to t2
-    boost::scoped_ptr<RTT::InputPort<double> > mi3(new RTT::InputPort<double>());
-    t2->addPort("mi3", *mi3);
-
-    // This test tests shared connections port-to-port connections.
-    ts  = corba::TaskContextServer::Create( tc, false ); //no-naming
-    ts2 = corba::TaskContextServer::Create( t2, false ); //no-naming
-
-    // must be running to catch event port signalling.
-    BOOST_CHECK( t2->start() );
-
-    // Create a CORBA policy specification
-    RTT::corba::CConnPolicy policy = toCORBA(ConnPolicy::data(ConnPolicy::LOCKED));
-    policy.init = false;
-    policy.transport = ORO_CORBA_PROTOCOL_ID; // force creation of non-local connections
-
-    corba::CDataFlowInterface_var ports  = ts->server()->ports();
-    corba::CDataFlowInterface_var ports2 = ts2->server()->ports();
-    double value = 0.0;
-
-    // Shared push connection...
-    policy.buffer_policy = RTT::corba::CShared;
-    policy.pull = false;
-    BOOST_CHECK( ports->createConnection("mo", ports2, "mi", policy) );
-    BOOST_CHECK( ports->createConnection("mo", ports2, "mi3", policy) );
-    BOOST_CHECK( ports2->createConnection("mo", ports2, "mi", policy) );
-    BOOST_CHECK( mi3->connected() );
-    BOOST_CHECK( mo2->connected() );
-    BOOST_REQUIRE( mi2->getManager()->getSharedConnection() );
-    BOOST_REQUIRE( mi3->getManager()->getSharedConnection() );
-    BOOST_CHECK_EQUAL( mi2->getManager()->getSharedConnection()->getName(), mi3->getManager()->getSharedConnection()->getName() );
-    BOOST_CHECK_EQUAL( mi3->read(value), NoData );
-    testPortDataConnection(); // communication between mo and mi should work the same as for private connections
-    BOOST_CHECK_EQUAL( mi3->read(value), OldData );
-    BOOST_CHECK_EQUAL( value, 2.0 );
-    BOOST_CHECK_EQUAL( mo2->write(3.0), WriteSuccess );
-    value = 0.0;
-    BOOST_CHECK_EQUAL( mi3->read(value), NewData );
-    BOOST_CHECK_EQUAL( value, 3.0 );
-    value = 0.0;
-    BOOST_CHECK_EQUAL( mi2->read(value), OldData );
-    BOOST_CHECK_EQUAL( value, 3.0 );
-
-    ports->disconnectPort("mo"); // disconnect from the output side
-    ports2->disconnectPort("mo"); // disconnect from the output side
-    BOOST_CHECK( !mo1->connected() );
-    BOOST_CHECK( !mo2->connected() );
-    BOOST_CHECK( !mi2->connected() );
-    BOOST_CHECK( !mi3->connected() );
-
-    // Shared pull connection...
-    policy.buffer_policy = RTT::corba::CShared;
-    policy.pull = true;
-    BOOST_CHECK( ports->createConnection("mo", ports2, "mi", policy) );
-    BOOST_CHECK( ports->createConnection("mo", ports2, "mi3", policy) );
-    BOOST_CHECK( ports2->createConnection("mo", ports2, "mi", policy) );
-    BOOST_CHECK( mi3->connected() );
-    BOOST_CHECK( mo2->connected() );
-    BOOST_REQUIRE( mi2->getManager()->getSharedConnection() );
-    BOOST_REQUIRE( mi3->getManager()->getSharedConnection() );
-    BOOST_CHECK_EQUAL( mi2->getManager()->getSharedConnection()->getName(), mi3->getManager()->getSharedConnection()->getName() );
-    BOOST_CHECK_EQUAL( mi3->read(value), NoData );
-    testPortDataConnection(); // communication between mo and mi should work the same as for private connections
-    BOOST_CHECK_EQUAL( mi3->read(value), OldData );
-    BOOST_CHECK_EQUAL( value, 2.0 );
-    BOOST_CHECK_EQUAL( mo2->write(3.0), WriteSuccess );
-    value = 0.0;
-    BOOST_CHECK_EQUAL( mi3->read(value), NewData );
-    BOOST_CHECK_EQUAL( value, 3.0 );
-    value = 0.0;
-    BOOST_CHECK_EQUAL( mi2->read(value), OldData );
-    BOOST_CHECK_EQUAL( value, 3.0 );
-
-    ports->disconnectPort("mo"); // disconnect from the output side
-    ports2->disconnectPort("mo"); // disconnect from the output side
-    BOOST_CHECK( !mo1->connected() );
-    BOOST_CHECK( !mo2->connected() );
-    BOOST_CHECK( !mi2->connected() );
-    BOOST_CHECK( !mi3->connected() );
-
-    // PerOutputPort pull connection...
-    policy.buffer_policy = RTT::corba::CPerOutputPort;
-    policy.pull = true;
-    BOOST_CHECK( ports->createConnection("mo", ports2, "mi", policy) );
-    BOOST_CHECK( ports->createConnection("mo", ports2, "mi3", policy) );
-    BOOST_CHECK( ports2->createConnection("mo", ports2, "mi", policy) ); // cannot use the DataFlowInterface CORBA API here, as it will find the local SharedConnection instance and fail.
-    BOOST_CHECK( mi3->connected() );
-    BOOST_CHECK( mo2->connected() );
-    BOOST_CHECK( mo1->getSharedBuffer() );
-    BOOST_CHECK( mo2->getSharedBuffer() );
-    BOOST_CHECK_EQUAL( mi3->read(value), NoData );
-    testPortDataConnection(); // communication between mo and mi should work the same as for private connections
-    BOOST_CHECK_EQUAL( mi3->read(value), OldData );
-    BOOST_CHECK_EQUAL( value, 2.0 );
-    BOOST_CHECK_EQUAL( mo1->write(3.0), WriteSuccess );
-    BOOST_CHECK_EQUAL( mo2->write(4.0), WriteSuccess );
-    value = 0.0;
-    BOOST_CHECK_EQUAL( mi3->read(value), NewData );
-    BOOST_CHECK_EQUAL( value, 3.0 );
-    value = 0.0;
-    BOOST_CHECK_EQUAL( mi2->read(value), NewData );
-    BOOST_CHECK_EQUAL( value, 4.0 );
-    value = 0.0;
-    BOOST_CHECK_EQUAL( mi3->read(value), OldData );
-    BOOST_CHECK_EQUAL( value, 3.0 );
-    value = 0.0;
-    BOOST_CHECK_EQUAL( mi2->read(value), OldData );
-    BOOST_CHECK_EQUAL( value, 4.0 );
-
-    ports2->disconnectPort("mi"); // disconnect from the input side
-    ports2->disconnectPort("mi3"); // disconnect from the input side
-    BOOST_CHECK( !mo1->connected() );
-    BOOST_CHECK( !mo2->connected() );
-    BOOST_CHECK( !mi2->connected() );
-    BOOST_CHECK( !mi3->connected() );
-}
-
 BOOST_AUTO_TEST_CASE( testPortProxying )
 {
     ts  = corba::TaskContextServer::Create( tc, false ); //no-naming
@@ -922,7 +790,7 @@ BOOST_AUTO_TEST_CASE( testDataHalfs )
 
     // test unbuffered Corba write --> C++ read
     cce = ports->buildChannelOutput("mi", policy);
-    cce->channelReady(policy);
+    ports->channelReady("mi", cce, policy);
     sample = new CORBA::Any();
     BOOST_REQUIRE( cce.in() );
 
@@ -980,7 +848,7 @@ BOOST_AUTO_TEST_CASE( testBufferHalfs )
 
     // test unbuffered Corba write --> C++ read
     cce = ports->buildChannelOutput("mi", policy);
-    cce->channelReady(policy);
+    ports->channelReady("mi", cce, policy);
     sample = new CORBA::Any();
     BOOST_REQUIRE( cce.in() );
 
