@@ -48,14 +48,19 @@ public:
         BOOST_CHECK( this->getTaskState() == TaskContext::PreOperational );
         BOOST_CHECK( this->getTargetState() == TaskContext::PreOperational );
 
+        expectedStateInStopHook = Running;
+        expectedTargetStateInStopHook = Stopped;
+        expectedStateInCleanupHook = Stopped;
+        expectedTargetStateInCleanupHook = PreOperational;
+
         this->resetFlags();
         validconfig = true;
         validstart = true;
         do_error = false;
         do_fatal = false;
-        do_throw=false;
-        do_throw2=false;
-        do_throw3=false;
+        do_throw_in_updateHook=false;
+        do_throw_in_errorHook=false;
+        do_throw_in_exceptionHook=false;
         do_trigger=false;
         do_breakUH=false;
         do_block=false;
@@ -97,27 +102,27 @@ public:
 
     void stopHook() {
         if (do_checks) {
-            BOOST_CHECK( mTaskState >= Running || mTaskState == Exception);
-            BOOST_CHECK( getTargetState() == Stopped || getTargetState() == Exception );
+            BOOST_CHECK_EQUAL(mTaskState, expectedStateInStopHook);
+            BOOST_CHECK_EQUAL(getTargetState(), expectedTargetStateInStopHook);
         }
         didstop = true;
     }
 
     void cleanupHook() {
         if (do_checks) {
-            BOOST_CHECK( mTaskState == Stopped || mTaskState == Exception);
-            BOOST_CHECK( getTargetState() == PreOperational || getTargetState() == Exception );
+            BOOST_CHECK_EQUAL(mTaskState, expectedStateInCleanupHook);
+            BOOST_CHECK_EQUAL(getTargetState(), expectedTargetStateInCleanupHook);
         }
         didcleanup = true;
     }
 
     void exceptionHook() {
         if (do_checks) {
-            BOOST_CHECK( mTaskState == Exception);
-            BOOST_CHECK( getTargetState() == Exception );
+            BOOST_CHECK_EQUAL(mTaskState, Running);
+            BOOST_CHECK_EQUAL(getTargetState(), Exception );
         }
         didexcept = true;
-        if (do_throw3)
+        if (do_throw_in_exceptionHook)
             throw A();
     }
 
@@ -132,7 +137,7 @@ public:
             this->fatal();
         if (do_error)
             this->error();
-        if (do_throw)
+        if (do_throw_in_updateHook)
             throw A();
         if (do_trigger) {
             this->trigger();
@@ -157,7 +162,7 @@ public:
         diderror = true;
         if (do_fatal)
             this->fatal();
-        if (do_throw2)
+        if (do_throw_in_errorHook)
             throw A();
     }
 
@@ -166,7 +171,9 @@ public:
     bool didstop;
     bool didcleanup;
     bool didupdate,diderror,didexcept, didbreakUH;
-    bool do_fatal, do_error, do_throw,do_throw2,do_throw3, do_trigger, do_breakUH, do_block, do_checks, do_stop;
+    bool do_fatal, do_error, do_throw_in_updateHook,do_throw_in_errorHook,do_throw_in_exceptionHook, do_trigger, do_breakUH, do_block, do_checks, do_stop;
+    TaskState expectedStateInStopHook, expectedTargetStateInStopHook;
+    TaskState expectedStateInCleanupHook, expectedTargetStateInCleanupHook;
     int  updatecount;
 };
 
@@ -517,6 +524,7 @@ BOOST_AUTO_TEST_CASE( testFailingTCStates)
     stc->validstart = false;
 
     // Failed configure() in PreOperational state:
+    BOOST_TEST_MESSAGE("Failed configure in PreOperational");
     BOOST_CHECK( stc->isConfigured() == false );
     BOOST_CHECK( stc->isRunning() == false );
     BOOST_CHECK( stc->configure() == false );
@@ -527,6 +535,7 @@ BOOST_AUTO_TEST_CASE( testFailingTCStates)
     stc->resetFlags();
 
     // Retry:
+    BOOST_TEST_MESSAGE("Retry configure");
     stc->validconfig = true;
     BOOST_CHECK( stc->configure() == true );
     BOOST_CHECK( stc->didconfig == true );
@@ -536,6 +545,7 @@ BOOST_AUTO_TEST_CASE( testFailingTCStates)
     stc->resetFlags();
 
     // Failed start() in Stopped state:
+    BOOST_TEST_MESSAGE("Failed start in Stopped");
     BOOST_CHECK( stc->start() == false );
     BOOST_CHECK( stc->didstart == true );
     BOOST_CHECK( stc->isRunning() == false );
@@ -544,6 +554,7 @@ BOOST_AUTO_TEST_CASE( testFailingTCStates)
     stc->resetFlags();
 
     // Retry:
+    BOOST_TEST_MESSAGE("Retry start");
     stc->validstart = true;
     BOOST_CHECK( stc->start() == true );
     BOOST_CHECK( stc->didstart == true );
@@ -553,6 +564,7 @@ BOOST_AUTO_TEST_CASE( testFailingTCStates)
     stc->resetFlags();
 
     // Error state by calling error().
+    BOOST_TEST_MESSAGE("Error state");
     stc->do_error = true;
     // Running state / updateHook :
     SimulationThread::Instance()->run(1);
@@ -562,14 +574,20 @@ BOOST_AUTO_TEST_CASE( testFailingTCStates)
     BOOST_CHECK( stc->isActive() == true );  // still active
     stc->resetFlags();
     stc->do_error = false;
+    BOOST_TEST_MESSAGE("Recover from Error");
     stc->recover();
     SimulationThread::Instance()->run(1);
     BOOST_CHECK( stc->isRunning() == true );
     BOOST_CHECK( stc->diderror == false );
     BOOST_CHECK( stc->didupdate == true );
 
-    // Error state by throwing in updateHook()
-    stc->do_throw = true;
+    // Exception state by throwing in updateHook()
+    BOOST_TEST_MESSAGE("Exception state");
+    stc->expectedStateInStopHook = TaskCore::Running;
+    stc->expectedTargetStateInStopHook = TaskCore::Exception;
+    stc->expectedStateInCleanupHook = TaskCore::Running;
+    stc->expectedTargetStateInCleanupHook = TaskCore::Exception;
+    stc->do_throw_in_updateHook = true;
     // Running state / updateHook :
     SimulationThread::Instance()->run(1);
     BOOST_CHECK( stc->inRunTimeError() == false );
@@ -577,7 +595,8 @@ BOOST_AUTO_TEST_CASE( testFailingTCStates)
     BOOST_CHECK( stc->didexcept == true );
     BOOST_CHECK( stc->isActive() == true );  // still active
     stc->resetFlags();
-    stc->do_throw = false;
+    stc->do_throw_in_updateHook = false;
+    BOOST_TEST_MESSAGE("Recover from Exception");
     stc->recover();
     SimulationThread::Instance()->run(1);
     BOOST_CHECK( stc->isConfigured() == false );
@@ -588,9 +607,14 @@ BOOST_AUTO_TEST_CASE( testFailingTCStates)
     stc->start();
 
     // Fatal Error state by throwing in exceptionHook()
+    BOOST_TEST_MESSAGE("Fatal error by throwing in updateHook and exceptionHook");
     stc->do_error = false;
-    stc->do_throw = true;
-    stc->do_throw3 = true;
+    stc->do_throw_in_updateHook = true;
+    stc->do_throw_in_exceptionHook = true;
+    stc->expectedStateInStopHook = TaskCore::Running;
+    stc->expectedTargetStateInStopHook = TaskCore::Exception;
+    stc->expectedStateInCleanupHook = TaskCore::Running;
+    stc->expectedTargetStateInCleanupHook = TaskCore::Exception;
     // Running state / updateHook :
     SimulationThread::Instance()->run(1);
     BOOST_CHECK( stc->inRunTimeError() == false );
@@ -741,5 +765,106 @@ BOOST_AUTO_TEST_CASE(testTaskCore_bails_out_if_startHook_returns_true_but_except
     BOOST_REQUIRE(task.inException());
 }
 
+struct calling_recover_and_configure_right_after_Exception_is_valid :
+    public RTT::TaskContext
+{
+    calling_recover_and_configure_right_after_Exception_is_valid()
+        : RTT::TaskContext("test", RTT::TaskContext::PreOperational)
+        , exceptionHookCalled(false)
+        , exceptionHookCalledWhileInConfigure(false) {}
+
+    bool configureHook()
+    {
+        exceptionHookCalledWhileInConfigure = exceptionHookCalled;
+        return true;
+    }
+    void updateHook()
+    {
+        usleep(100000);
+        exception();
+    }
+    void exceptionHook()
+    {
+        usleep(100000);
+
+        exceptionHookCalled = true;
+    }
+
+    bool exceptionHookCalled, exceptionHookCalledWhileInConfigure;
+};
+BOOST_AUTO_TEST_CASE(test_calling_recover_and_configure_right_after_Exception_is_valid) {
+    calling_recover_and_configure_right_after_Exception_is_valid task;
+    task.configure();
+    task.start();
+    BOOST_REQUIRE(!task.inException());
+    task.trigger();
+    while(!task.inException()) { usleep(1000); }
+    task.recover();
+    task.configure();
+    BOOST_REQUIRE(task.exceptionHookCalledWhileInConfigure);
+}
+
+struct calling_stop_concurrently_with_updateHook_calling_exception_works_as_expected :
+    public RTT::TaskContext
+{
+    calling_stop_concurrently_with_updateHook_calling_exception_works_as_expected()
+        : RTT::TaskContext("test", RTT::TaskContext::PreOperational)
+        , stopHookCalled(0) {}
+
+    void updateHook()
+    {
+        usleep(100000);
+        exception();
+    }
+    void stopHook()
+    {
+        ++stopHookCalled;
+    }
+
+    int stopHookCalled;
+};
+BOOST_AUTO_TEST_CASE(test_calling_stop_concurrently_with_updateHook_calling_exception_works_as_expected) {
+    calling_stop_concurrently_with_updateHook_calling_exception_works_as_expected task;
+    task.configure();
+    task.start();
+    BOOST_REQUIRE(!task.inException());
+    task.trigger();
+    task.stop();
+    BOOST_REQUIRE_EQUAL(1, task.stopHookCalled);
+    BOOST_REQUIRE_EQUAL(TaskCore::Exception, task.getTaskState());
+    BOOST_REQUIRE_EQUAL(TaskCore::Exception, task.getTargetState());
+}
+
+struct calling_stop_concurrently_with_updateHook_calling_stop_works_as_expected :
+    public RTT::TaskContext
+{
+    calling_stop_concurrently_with_updateHook_calling_stop_works_as_expected()
+        : RTT::TaskContext("test", RTT::TaskContext::PreOperational)
+        , stopHookCalled(0) {}
+
+    void updateHook()
+    {
+        usleep(100000);
+        stop();
+    }
+    void stopHook()
+    {
+        ++stopHookCalled;
+    }
+
+    int stopHookCalled;
+};
+BOOST_AUTO_TEST_CASE(test_calling_stop_concurrently_with_updateHook_calling_stop_works_as_expected) {
+    calling_stop_concurrently_with_updateHook_calling_stop_works_as_expected task;
+    task.configure();
+    task.start();
+    BOOST_REQUIRE(!task.inException());
+    task.trigger();
+    task.stop();
+    BOOST_REQUIRE_EQUAL(1, task.stopHookCalled);
+    BOOST_REQUIRE_EQUAL(TaskCore::Stopped, task.getTaskState());
+    BOOST_REQUIRE_EQUAL(TaskCore::Stopped, task.getTargetState());
+}
+
 BOOST_AUTO_TEST_SUITE_END()
 
